@@ -163,11 +163,20 @@ def get_auth_params(
 def get_audience_for_wallet(ctx: click.Context, wallet_url: str) -> list:
     urls = []
     for service in SUPPORTED_SERVICES:
+
         if (
-            get_config(ctx, var_path=[service, "wallet", "url"], raise_error=False)
+            get_config(
+                ctx,
+                var_path=[service.replace("-", "_"), "wallet", "url"],
+                raise_error=False,
+            )
             == wallet_url
         ):
-            urls.append(get_config(ctx, var_path=[service, "url"], raise_error=False))
+            urls.append(
+                get_config(
+                    ctx, var_path=[service.replace("-", "_"), "url"], raise_error=False
+                )
+            )
     return urls
 
 
