@@ -1,10 +1,10 @@
-from urllib.parse import urlparse
+from urllib.parse import urlparse, urlunparse
 
 import click
 import urllib3
 import threading
 import os
-from typing import Optional
+from typing import Optional, Union
 from dnastack.constants import *
 from requests import Response
 from requests.exceptions import HTTPError
@@ -20,11 +20,12 @@ output_lock = threading.Lock()
 exit_code_lock = threading.Lock()
 
 
-def get_host(url):
-    return re.search(r"(?<=https://)([^/])+(?=/.*)", url).group(0)
+def get_host(url: str) -> str:
+    parsed_url = urlparse(url)
+    return parsed_url.netloc
 
 
-def handle_file_response(download_file, data):
+def handle_file_response(download_file: str, data: Union[str, bytes]) -> str:
     # decode if fasta
     if re.search(r"\.fa", download_file):
         data = data.decode("utf-8")
@@ -32,8 +33,8 @@ def handle_file_response(download_file, data):
     return data
 
 
-def file_to_dataframe(download_file, data):
-    # turn into dataframe for FASTA/FASTQ files, otherwise just return raw data
+# turn into dataframe for FASTA/FASTQ files, otherwise just return raw data
+def file_to_dataframe(download_file: str, data: Union[str, bytes]):
     if re.search(r"\.fa", download_file):
         data = data.split("\n", maxsplit=1)
 
@@ -45,24 +46,27 @@ def file_to_dataframe(download_file, data):
     return data
 
 
-def is_drs_url(url):
-    return url[:6] == "drs://"
+def is_drs_url(url: str) -> bool:
+    parsed_url = urlparse(url)
+    return parsed_url.scheme == "drs"
 
 
-def get_object_info_url_from_drs(url):
-    drs_host = re.search(r"(?<=drs://)([^/])+(?=/.*)", url)
-    if not drs_host:
-        raise Exception(f"Could not get drs host from url {url}")
-    object_url = f"https://{drs_host.group(0)}/ga4gh/drs/v1/"
-    return object_url, drs_host
+def get_object_info_url_from_drs(url: str) -> tuple:
+    if not is_drs_url(url):
+        raise Exception(f"[{url}] is not a DRS url")
+    parsed_url = urlparse(url)
+    object_url = str(
+        urlunparse(("https", parsed_url.netloc, "/ga4gh/drs/v1/", "", "", ""))
+    )
+    return object_url, parsed_url.netloc
 
 
-def get_object_id_from_drs(url):
+def get_object_id_from_drs(url: str) -> str:
     object_id = re.search(r"(?<=/)(\w{8}-\w{4}-\w{4}-\w{4}-\w{12})", url)
     if object_id:
         return object_id.group(0)
     else:
-        raise Exception(f"Could not get drs object id from url {url}")
+        raise Exception(f"Could not get drs object id from url [{url}]")
 
 
 def get_filename_from_url(url: str) -> str:
@@ -225,5 +229,5 @@ def download_files(
     if len(failed_downloads) > 0:
         error_msg = f"One or more downloads failed:\n"
         for failure in failed_downloads:
-            error_msg += f"{failure['url']} failed with code {failure['code']}: {failure['message']}\n"
+            error_msg += f"[{failure['url']}] failed with code {failure['code']}: {failure['message']}\n"
         raise Exception(error_msg)
