@@ -6,7 +6,7 @@ import csv
 from io import StringIO
 from dnastack import __main__ as dnastack_cli
 
-from .utils import assert_has_property
+from .utils import *
 from .. import *
 
 
@@ -14,14 +14,25 @@ class TestCliDataConnectQueryCommand(unittest.TestCase):
     def setUp(self):
         self.runner = CliRunner()
         self.data_connect_url = TEST_DATA_CONNECT_URI
-        self.runner.invoke(
-            dnastack_cli.dnastack,
-            [
-                "config",
-                "set",
-                "data-connect-url",
-                self.data_connect_url,
-            ],
+        self.wallet_url = TEST_AUTH_PARAMS["publisher"]["url"]
+
+        clear_config()
+        set_cli_config(self.runner, "data_connect.url", self.data_connect_url)
+        set_auth_params_for_service(
+            self.runner,
+            service="data-connect",
+            auth_params=TEST_AUTH_PARAMS["publisher"],
+        )
+        set_cli_config(
+            self.runner,
+            f"oauth|{self.wallet_url}|scope",
+            TEST_AUTH_SCOPES["publisher"],
+            delimiter="|",
+        )
+        login_with_refresh_token_for_service(
+            self.runner,
+            service="data-connect",
+            refresh_token=TEST_WALLET_REFRESH_TOKEN["publisher"],
         )
 
     def test_variant_query(self):
