@@ -21,9 +21,8 @@ class TestClientLibraryFilesCommand(unittest.TestCase):
         )
 
         # clean up ./out directory
-        pathlib.Path(f"{os.getcwd()}/out/{TEST_DRS_FILENAMES[0]}").unlink(
-            missing_ok=True
-        )
+        if pathlib.Path(f"{os.getcwd()}/out/{TEST_DRS_FILENAMES[0]}").exists():
+            pathlib.Path(f"{os.getcwd()}/out/{TEST_DRS_FILENAMES[0]}").unlink()
         pathlib.Path(f"{os.getcwd()}/out").rmdir()
 
     def test_multiple_drs_download(self):
@@ -37,7 +36,8 @@ class TestClientLibraryFilesCommand(unittest.TestCase):
 
         # clean up ./out directory
         for drs_file in TEST_DRS_FILENAMES:
-            pathlib.Path(f"{os.getcwd()}/out/{drs_file}").unlink(missing_ok=True)
+            if pathlib.Path(f"{os.getcwd()}/out/{drs_file}").exists():
+                pathlib.Path(f"{os.getcwd()}/out/{drs_file}").unlink()
 
         pathlib.Path(f"{os.getcwd()}/out").rmdir()
 
